# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os
import uuid
from django.db import models

from django_chaas_backend.conf import settings


class Repository(models.Model):
    STATUS_UNKNOWN = u'unknown'
    STATUS_CLONING = u'cloning'
    STATUS_CLONE_ERROR = u'clone-error'
    STATUS_CLONED = u'cloned'
    STATUS_UPDATING = u'updating'
    STATUS_READY = u'ready'
    STATUS = (
        (STATUS_UNKNOWN, u'Unknown'),
        (STATUS_CLONING, u'Cloning'),
        (STATUS_CLONED, u'Cloned'),
        (STATUS_UPDATING, u'Updating'),
        (STATUS_READY, u'Ready'),
    )
    uuid = models.UUIDField(unique=True, default=uuid.uuid4, editable=False)
    created = models.DateTimeField(auto_now_add=True)
    updated = models.DateTimeField(null=True, auto_now=True)
    status = models.CharField(max_length=30, choices=STATUS,
                              default=STATUS_UNKNOWN)
    url = models.URLField(help_text='URL to a repository. '
                          'I.e. "https://github.com/toabctl/oxcli.git"',
                          unique=True)

    class Meta:
        ordering = ('updated', 'created', 'status')

    def __str__(self):
        return '<Repository %s (status: %s; uuid: %s)>' % (
            self.url, self.status, self.uuid)

    @property
    def path(self):
        """filesystem path where the repository can be found"""
        return os.path.join(settings.CHAAS_REPOSITORY_PATH, str(self.uuid))
