# -*- coding: utf-8 -*-
from django.core.exceptions import ObjectDoesNotExist

from rest_framework import viewsets
from rest_framework.response import Response
from rest_framework import status

from models import Repository
from serializers import RepositorySerializer, ChangelogSerializer

from django_chaas_backend import common


class RepositoryViewSet(viewsets.ModelViewSet):
    """
    API endpoint that allows users to edit/add repositories
    """
    queryset = Repository.objects.all()
    serializer_class = RepositorySerializer
    lookup_field = 'uuid'


class ChangelogViewSet(viewsets.ViewSet):
    serializer_class = ChangelogSerializer
    lookup_field = 'uuid'

    def create(self, request):
        serializer = ChangelogSerializer(data=request.data)
        if serializer.is_valid():
            # get repository
            try:
                repository = Repository.objects.get(
                    uuid=serializer.data['repository_uuid'])
            except ObjectDoesNotExist:
                return Response(status=status.HTTP_404_NOT_FOUND,
                                data={'error': 'repository %s not found' %
                                      (serializer.data['repository_uuid'])})
            # get changelog between revision1 and revision2
            try:
                chlog = common.repo_git_changelog(repository.path,
                                                  serializer.data['rev1'],
                                                  serializer.data['rev2'])
            except common.ChaasChangelogError as e:
                return Response(
                    status=status.HTTP_400_BAD_REQUEST, data={'error': str(e)})
            else:
                return Response(chlog)
        else:
            return Response(
                serializer.errors, status=status.HTTP_400_BAD_REQUEST)
